@@ -258,7 +258,7 @@ extern "C"
      * @return the created item
      * @sa #plist_type
      */
-    PLIST_API plist_t plist_new_data(const uint8_t *val, uint64_t length);
+    PLIST_API plist_t plist_new_data(const char *val, uint64_t length);
 
     /**
      * Create a new plist_t type #PLIST_DATE
@@ -445,7 +445,7 @@ extern "C"
     PLIST_API void plist_dict_get_item_key(plist_t node, char **key);
 
     /**
-     * Get the item for given key in a #PLIST_DICT node.
+     * Get the nth item in a #PLIST_DICT node.
      *
      * @param node the node of type #PLIST_DICT
      * @param key the identifier of the item to get.
@@ -755,7 +755,7 @@ extern "C"
      * @param length the length of the buffer
      * @note Use plist_mem_free() to free the allocated memory.
      */
-    PLIST_API void plist_get_data_val(plist_t node, uint8_t **val, uint64_t * length);
+    PLIST_API void plist_get_data_val(plist_t node, char **val, uint64_t * length);
 
     /**
      * Get a pointer to the data buffer of a #PLIST_DATA node.
@@ -768,7 +768,7 @@ extern "C"
      *
      * @return Pointer to the buffer
      */
-    PLIST_API const uint8_t* plist_get_data_ptr(plist_t node, uint64_t* length);
+    PLIST_API const char* plist_get_data_ptr(plist_t node, uint64_t* length);
 
     /**
      * Get the value of a #PLIST_DATE node.
@@ -860,7 +860,7 @@ extern "C"
      *		be freed by the node.
      * @param length the length of the buffer
      */
-    PLIST_API void plist_set_data_val(plist_t node, const uint8_t *val, uint64_t length);
+    PLIST_API void plist_set_data_val(plist_t node, const char *val, uint64_t length);
 
     /**
      * Set the value of a node.
